package com.ruoyi.mall.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.mall.mapper.MallBannerMapper;
import com.ruoyi.mall.domain.MallBanner;
import com.ruoyi.mall.service.IMallBannerService;

import javax.annotation.Resource;

/**
 * 轮播图Service业务层处理
 *
 * @author LCL
 * @date 2023-07-11
 */
@Service
public class MallBannerServiceImpl implements IMallBannerService
{
    @Resource
    private MallBannerMapper mallBannerMapper;

    /**
     * 查询轮播图
     *
     * @param id 轮播图主键
     * @return 轮播图
     */
    @Override
    public MallBanner selectMallBannerById(Long id)
    {
        return mallBannerMapper.selectMallBannerById(id);
    }

    /**
     * 查询轮播图列表
     *
     * @param mallBanner 轮播图
     * @return 轮播图
     */
    @Override
    public List<MallBanner> selectMallBannerList(MallBanner mallBanner)
    {
        return mallBannerMapper.selectMallBannerList(mallBanner);
    }

    /**
     * 新增轮播图
     *
     * @param mallBanner 轮播图
     * @return 结果
     */
    @Override
    public int insertMallBanner(MallBanner mallBanner)
    {
        mallBanner.setCreateAt(DateUtils.getTime());
        return mallBannerMapper.insertMallBanner(mallBanner);
    }

    /**
     * 修改轮播图
     *
     * @param mallBanner 轮播图
     * @return 结果
     */
    @Override
    public int updateMallBanner(MallBanner mallBanner)
    {
        mallBanner.setUpdateAt(DateUtils.getTime());
        return mallBannerMapper.updateMallBanner(mallBanner);
    }

    /**
     * 批量删除轮播图
     *
     * @param ids 需要删除的轮播图主键
     * @return 结果
     */
    @Override
    public int deleteMallBannerByIds(Long[] ids)
    {
        return mallBannerMapper.deleteMallBannerByIds(ids);
    }

    /**
     * 删除轮播图信息
     *
     * @param id 轮播图主键
     * @return 结果
     */
    @Override
    public int deleteMallBannerById(Long id)
    {
        return mallBannerMapper.deleteMallBannerById(id);
    }
}
